@@ -3,10 +3,11 @@ use strict;
 use warnings;
 
 package Dist::Zilla::Plugin::SynopsisTests;
-our $VERSION = '1.100700';
-# ABSTRACT: release tests for synopses
+BEGIN {
+  $Dist::Zilla::Plugin::SynopsisTests::VERSION = '1.101420';
+}
+# ABSTRACT: Release tests for synopses
 use Moose;
-use Test::Synopsis;
 extends 'Dist::Zilla::Plugin::InlineFiles';
 
 __PACKAGE__->meta->make_immutable;
@@ -20,11 +21,11 @@ no Moose;
 
 =head1 NAME
 
-Dist::Zilla::Plugin::SynopsisTests - release tests for synopses
+Dist::Zilla::Plugin::SynopsisTests - Release tests for synopses
 
 =head1 VERSION
 
-version 1.100700
+version 1.101420
 
 =head1 SYNOPSIS
 
@@ -35,7 +36,7 @@ In C<dist.ini>:
 =head1 DESCRIPTION
 
 This is an extension of L<Dist::Zilla::Plugin::InlineFiles>, providing the
-following files
+following file:
 
   xt/release/synopsis.t - a standard Test::Synopsis test
 
@@ -46,6 +47,25 @@ __END__
 
 See perlmodinstall for information and options on installing Perl modules.
 
+=head1 BUGS AND LIMITATIONS
+
+No bugs have been reported.
+
+Please report any bugs or feature requests through the web interface at
+L<http://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-SynopsisTests>.
+
+=head1 AVAILABILITY
+
+The latest version of this module is available from the Comprehensive Perl
+Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
+site near you, or see
+L<http://search.cpan.org/dist/Dist-Zilla-Plugin-SynopsisTests/>.
+
+The development version lives at
+L<http://github.com/hanekomu/Dist-Zilla-Plugin-SynopsisTests/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
+
 =head1 AUTHOR
 
   Marcel Gruenauer <marcel@cpan.org>
